@@ -17,9 +17,8 @@ def patch_init(mocker):
     """
     Makes patching a class' constructor slightly easier
     """
-    def patch_init(item, autospec=True, **kwargs):
-        mocker.patch.object(item, '__init__', return_value=None,
-                            autospec=autospec, **kwargs)
+    def patch_init(item, **kwargs):
+        mocker.patch.object(item, '__init__', return_value=None, **kwargs)
     return patch_init
 
 
